using System;
using System.Windows.Forms;
using System.Text.RegularExpressions;
using System.Xml;

using com.ibm.gre;

namespace SampleApp
{
	/// <summary>
	/// Summary description for Util.
	/// </summary>
	public class Util
	{
		private Form1 m_parent;
		private Control m_currentForm;

		public Util(Control currentForm, Control loggingForm)
		{
			m_currentForm = currentForm;
			m_parent = (Form1)loggingForm;
		}

		public void log(string msg)
		{
			m_parent.log(m_currentForm.Name, msg);
		}

		public void appendText(string msg)
		{
			m_parent.appendText(msg);
		}

		public void showSoapException(System.Web.Services.Protocols.SoapException s)
		{
			MessageBox.Show("WebException: " + s.Message);
		}

		public bool checkForTimeOut(string message)
		{
			Regex r = new Regex(".*com.ibm.ejs.container.SessionBeanTimeoutException.*");
			return r.IsMatch(message);
		}

		static public void showWebException(System.Net.WebException we)
		{
			MessageBox.Show("WebException: " + we.Message);
		}

		public void logWebException(System.Net.WebException we)
		{
			log("\r\nWebException" +
				"\r\n\r\nMessage: " + we.Message +
				"\r\n\r\nSource: " + we.Source +
				"\r\n\r\nResponse : " + we.Response +
				"\r\n\r\nStatus : " + we.Status +
				"\r\n\r\nTargetSite : " + we.TargetSite +
				"\r\n\r\nStackTrace: " + we.StackTrace);
		}

		public void logRecordsManagerError(string message)
		{
			XmlDocument doc = new XmlDocument();
			try
			{
				doc.LoadXml(message);
				XmlNodeList errorNodes = doc.GetElementsByTagName("Error");
				log("Records Manager Error: ");
				for(int i = 0; i < errorNodes.Count; i++)
				{
					XmlNodeList errElements = errorNodes.Item(i).ChildNodes;
					for(int l = 0; l < errElements.Count; l++)
					{
						XmlNode errNode = errElements.Item(l);
						appendText(errNode.Value);
					}
				}
			}
			catch(XmlException e)
			{
				logXMLErr(e, "Records Manager Exception");
			}
		}

		public void logXMLErr(XmlException e,string msg)
		{
			log(msg +
				"\r\nXmlException: " + e.Message +
				"\r\nSource: " + e.Source +
				"\r\nLineNumber: " + e.LineNumber +
				"\r\nPosition: " + e.LinePosition);
		}

		public bool handleSoapException(System.Web.Services.Protocols.SoapException s, bool checkTimeOut)
		{
			if(checkTimeOut)
			{
				if(checkForTimeOut(s.Message))
				{
					m_parent.irmFactory.reLogin();
					log("\r\nSESSION BEAN TIMED OUT\r\n\r\nYou were logged in again.\r\n\r\nTry again.");
					return true;
				}
			}
			
			//If the message contains XML display the Error elements
			logRecordsManagerError(s.Message);
			
			//Show exception information
			log("SoapException" +
				"\r\n\r\nCode:\t" + s.Code +
				"\r\n\r\nMessage:\t" + s.Message +
				"\r\n\r\nDetail:\t" + s.Detail +
				"\r\n\r\nTargetSite:\t" + s.TargetSite +
				"\r\n\r\nActor:\t" + s.Actor +
				"\r\n\r\nStackTrace:\t" + s.StackTrace);

			return false;
		}

		public static string makeStatusMsg(int status)
		{
			if(status > 0)
			{
				if(status == 100)
				{
					return "COMPLETED";
				}
				return "IN PROGRESS";
			}
			else
			{
				switch((IRMConstants.BatchResultStatusTypes)status)
				{
					case IRMConstants.BatchResultStatusTypes.CANCELED:
						return "CANCELED";
					case IRMConstants.BatchResultStatusTypes.COMPLETED:
						return "COMPLETED";
					case IRMConstants.BatchResultStatusTypes.COMPLETED_PENDING_USER_CONFIRMATION:
						return "COMPLETED_PENDING_USER_CONFIRMATION";
					case IRMConstants.BatchResultStatusTypes.COMPLETED_WITH_ERRORS:
						return "COMPLETED_WITH_ERRORS";
					case IRMConstants.BatchResultStatusTypes.COMPLETED_WITH_ERRORS_PENDING_USER_CONFIRMATION:
						return "COMPLETED_WITH_ERRORS_PENDING_USER_CONFIRMATION";
					case IRMConstants.BatchResultStatusTypes.CONVERTING_METADATA_TO_SCHEMA:
						return "CONVERTING_METADATA_TO_SCHEMA";
					case IRMConstants.BatchResultStatusTypes.FAILED:
						return "FAILED";
					case IRMConstants.BatchResultStatusTypes.RECEIVED:
						return "RECEIVED";
					case IRMConstants.BatchResultStatusTypes.SCHEDULED_TO_CANCEL:
						return "SCHEDULED_TO_CANCEL";
					case IRMConstants.BatchResultStatusTypes.STARTED:
						return "STARTED";
					default:
						return System.Convert.ToString(status);
				}
			}
		}

	}
}
