/*
 * Created on Dec 30, 2004
 */
package com.ibm.gre.samples.collectionhelpers;

import org.w3c.dom.Element;
import com.ibm.gre.engine.util.XMLUtil;

/**
 * 	Represents a single line that will be displayed in a QueryForm
 *  A Line also represents parts of the Query element
 *  in a Records Manager XML Query string.
 *  Each line is either a FieldExpression or an InterFieldOperator or
 *  one of a limited number of optional fields.
 */
public class Line {
	
	private Element m_fieldElement;
	private int m_nFlPlnCmpntAttrDefDatTyp;
	private String m_key;
	private String m_caption;
	private int m_pickListId;
	private int m_lineType;
	private int m_controlType;
	private byte m_tab;

	/**
	 * Constructor for a Line object
	 * @param fieldElement The FieldValue element of a FieldExpression, or null if not used.
	 * @param nFlPlnCmpntAttrDefDatTyp The data type of the FieldValue, or 0 if not relevant.
	 * @param key The name of the XML element this line represents.
	 * @param caption The Caption to display.
	 * @param pickListId The ID of a picklist associated with the FieldValue.
	 * @param lineType The type of line to display.
	 * See LineType.
	 * @param controlType The type of control that is used on this line.
	 * @param tab The number of tab characters appended to the line.
	 */
	public Line
	(
		Element fieldElement,
		int nFlPlnCmpntAttrDefDatTyp,
		String key,
		String caption,
		int pickListId,
		int lineType,
		int controlType,
		byte tab
	)
	{
		m_fieldElement = fieldElement;
		m_nFlPlnCmpntAttrDefDatTyp = nFlPlnCmpntAttrDefDatTyp;
		m_key = key;
		m_caption = caption;
		m_pickListId = pickListId;
		m_lineType = lineType;
		m_controlType = controlType;
		m_tab = tab;
	}

	/**
	 * The caption to display for this line.
	 * @return String
	 */
	public String getCaption() {
		return m_caption;
	}

	/**
	 * The type of UI control that will be associated with the line.
	 * @return int See com.ibm.gre.engine.util.ProfileControlType
	 */
	public int getControlType() {
		return m_controlType;
	}

	/**
	 * The XML element that is associated with this line.
	 * In some cases this will be a FieldValue, Scope or optional field.
	 * @return Element The XML element that is associated with
	 * this Line.
	 */
	public Element getFieldElement() {
		return m_fieldElement;
	}

	/**
	 * Sets the value for the XML element that is associated with this line.
	 * @param val The value to set.
	 */
	public void setFieldElement(String val)
	{
		XMLUtil.setValue(m_fieldElement,val);
	}
	
	/**
	 * The name of the XML eleement represented by this line.
	 * @return String
	 */
	public String getKey() {
		return m_key;
	}

	/**
	 * The type of line that will be displayed.
	 * For example LineType.SCOPE
	 * @return int See LineType.
	 */
	public int getLineType() {
		return m_lineType;
	}

	/**
	 * The data type represented on this line
	 * @return int See com.ibm.gre.engine.util.AttributeDataTypes
	 */
	public int getFlPlnCmpntAttrDefDatTyp() {
		return m_nFlPlnCmpntAttrDefDatTyp;
	}

	/**
	 * The Picklist ID associated with the line.
	 * @return int
	 */
	public int getPickListId() {
		return m_pickListId;
	}

	/**
	 * @return byte
	 */
	public byte getTab() {
		return m_tab;
	}

}
